pub struct GroupMethods { /* private fields */ }Expand description
Methods for group membership lookups (circles_getGroupMemberships, circles_getGroups).
Implementations
Sourceimpl GroupMethods
impl GroupMethods
Sourcepub async fn get_memberships(
&self,
avatar: Address,
) -> Result<Vec<GroupMembershipRow>>
pub async fn get_memberships( &self, avatar: Address, ) -> Result<Vec<GroupMembershipRow>>
circles_getGroupMemberships
Sourcepub fn get_group_memberships(
&self,
avatar: Address,
limit: u32,
sort_order: SortOrder,
) -> PagedQuery<GroupMembershipRow>
pub fn get_group_memberships( &self, avatar: Address, limit: u32, sort_order: SortOrder, ) -> PagedQuery<GroupMembershipRow>
Paged GroupMemberships query filtered by member address.
Sourcepub fn get_group_members(
&self,
group: Address,
limit: u32,
sort_order: SortOrder,
) -> PagedQuery<GroupMembershipRow>
pub fn get_group_members( &self, group: Address, limit: u32, sort_order: SortOrder, ) -> PagedQuery<GroupMembershipRow>
Paged GroupMemberships query filtered by group address.
Sourcepub fn get_group_holders(
&self,
group: Address,
limit: u32,
) -> PagedQuery<GroupTokenHolderRow>
pub fn get_group_holders( &self, group: Address, limit: u32, ) -> PagedQuery<GroupTokenHolderRow>
Paged GroupTokenHoldersBalance query matching the TS group holders helper.
Sourcepub fn get_groups_paged(
&self,
limit: u32,
params: Option<GroupQueryParams>,
sort_order: SortOrder,
) -> PagedQuery<GroupRow>
pub fn get_groups_paged( &self, limit: u32, params: Option<GroupQueryParams>, sort_order: SortOrder, ) -> PagedQuery<GroupRow>
Paged Groups query with optional filters matching the TS helper.
Sourcepub async fn find_groups(
&self,
limit: u32,
params: Option<GroupQueryParams>,
) -> Result<Vec<GroupRow>>
pub async fn find_groups( &self, limit: u32, params: Option<GroupQueryParams>, ) -> Result<Vec<GroupRow>>
Fetch groups across pages until limit rows are collected.