pub struct TrustMethods { /* private fields */ }Expand description
Methods for trust relation queries.
Wraps circles_getTrustRelations and circles_getCommonTrust.
Implementations
Sourceimpl TrustMethods
impl TrustMethods
Sourcepub async fn get_trust_relations(
&self,
address: Address,
) -> Result<Vec<TrustRelation>>
pub async fn get_trust_relations( &self, address: Address, ) -> Result<Vec<TrustRelation>>
circles_getTrustRelations
Sourcepub async fn get_aggregated_trust_relations(
&self,
avatar: Address,
) -> Result<Vec<AggregatedTrustRelation>>
pub async fn get_aggregated_trust_relations( &self, avatar: Address, ) -> Result<Vec<AggregatedTrustRelation>>
circles_getAggregatedTrustRelations
Sourcepub async fn get_common_trust(
&self,
avatar_a: Address,
avatar_b: Address,
) -> Result<Vec<TrustRelationType>>
pub async fn get_common_trust( &self, avatar_a: Address, avatar_b: Address, ) -> Result<Vec<TrustRelationType>>
circles_getCommonTrust
Sourcepub async fn get_trusted_by(
&self,
avatar: Address,
) -> Result<Vec<AggregatedTrustRelation>>
pub async fn get_trusted_by( &self, avatar: Address, ) -> Result<Vec<AggregatedTrustRelation>>
Filter aggregated relations to only the avatars that trust avatar.
Sourcepub async fn get_trusts(
&self,
avatar: Address,
) -> Result<Vec<AggregatedTrustRelation>>
pub async fn get_trusts( &self, avatar: Address, ) -> Result<Vec<AggregatedTrustRelation>>
Filter aggregated relations to only the avatars trusted by avatar.
Sourcepub async fn get_mutual_trusts(
&self,
avatar: Address,
) -> Result<Vec<AggregatedTrustRelation>>
pub async fn get_mutual_trusts( &self, avatar: Address, ) -> Result<Vec<AggregatedTrustRelation>>
Filter aggregated relations to mutual trust edges only.